window.Gleam.initSearch([{"doc":"esgleam","title":"esgleam","content":"# esgleam\n\n[![Package Version](https://img.shields.io/hexpm/v/esgleam)](https://hex.pm/packages/esgleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/esgleam/)\n\n*esbuild for Gleam that works on Erlang &amp; JavaScript.*\n\n## Quick start\n\n1. Create a Gleam project as you would normally and make sure you have a file in `src` with the name of your project (as specified in `gleam.toml`)\n\n2. Install `esbuild`\n```sh\n$ gleam run -m esgleam/install\n```\n\n3.\n```sh\n$ gleam run -m esgleam/bundle\n```\nSee `/dist` for your bundled code\n\n4. To start a development server\n```sh\n$ gleam run -m esgleam/serve\n```\n\n## Advanced Usage\n\n(Follow steps 1-2)\n\n3. Create `/src/build.gleam` with the following\n```gleam\nimport esgleam\n\npub fn main() {\n   esgleam.new(&quot;./dist/static&quot;)\n   |&gt; esgleam.entry(&quot;main.gleam&quot;)\n   |&gt; esgleam.target(&quot;esnext&quot;)\n   |&gt; esgleam.target(&quot;firefox110&quot;)\n   |&gt; esgleam.bundle\n}\n```\n\n5. Run your build script\n```sh\n$ gleam run -m build\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add esgleam\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/esgleam&gt;.\n\n## Roadmap\n- [ ] Create file watcher for `*.gleam` which runs on both Erlang and JavaScript\n- [ ] Fix bug with STDOUT/STDERR not being shown when running `esbuild` in the erlang target\n- [ ] Write tests for config options\n- [ ] Add more config options if needed\n- [ ] Pseudo-SourceMaps until [#1341](https://github.com/gleam-lang/gleam/discussions/1341) merges\n- [ ] Consider creating a way to use plugins\n- [ ] Hot Module Reloading?????\n","url":"index.html"},{"doc":"esgleam","title":"Config","content":"pub type Config {\n  Config(\n    outdir: String,\n    entry_points: List(String),\n    format: Format,\n    kind: Kind,\n    minify: Bool,\n    target: List(String),\n    serve: Option(String),\n    sourcemap: Bool,\n    watch: Bool,\n    raw: String,\n  )\n}\n Config for esbuild\nConfig(\n  outdir: String,\n  entry_points: List(String),\n  format: Format,\n  kind: Kind,\n  minify: Bool,\n  target: List(String),\n  serve: Option(String),\n  sourcemap: Bool,\n  watch: Bool,\n  raw: String,\n)\n\noutdir\n&lt;p&gt;Output directory&lt;/p&gt;\n\nentry_points\n&lt;p&gt;List of entry points supplied&lt;/p&gt;\n\nformat\n&lt;p&gt;Output format for JavaScript. See &lt;a href=&quot;#Format&quot;&gt;&lt;code&gt;Format&lt;/code&gt;&lt;/a&gt;&lt;br /&gt;\ndefault &lt;code&gt;Esm&lt;/code&gt;&lt;/p&gt;\n\nkind\n&lt;p&gt;Kind for output&lt;br /&gt;\ndefault &lt;code&gt;Library&lt;/code&gt;&lt;/p&gt;\n\nminify\n&lt;p&gt;default &lt;code&gt;False&lt;/code&gt;&lt;/p&gt;\n\ntarget\n&lt;p&gt;List of &lt;a href=&quot;https://esbuild.github.io/api/#target&quot;&gt;target environments&lt;/a&gt;&lt;br /&gt;\ndefault &lt;code&gt;[]&lt;/code&gt;&lt;/p&gt;\n\nserve\n&lt;p&gt;The root directory for the dev server (run server when defined)&lt;br /&gt;\ndefault &lt;code&gt;None&lt;/code&gt;&lt;/p&gt;\n\nsourcemap\n&lt;p&gt;Generate sourcemap for JavaScript&lt;br /&gt;\ndefault &lt;code&gt;False&lt;/code&gt;&lt;/p&gt;\n\nwatch\n&lt;p&gt;Enable watchmode. Bundles files on change&lt;br /&gt;\nNote: &lt;code&gt;gleam build&lt;/code&gt; need to be run manually&lt;br /&gt;\ndefault &lt;code&gt;False&lt;/code&gt;&lt;/p&gt;\n\nraw\n&lt;p&gt;raw flags to pass to esbuild&lt;br /&gt;\ndefault &lt;code&gt;&amp;quot;&amp;quot;&lt;/code&gt;&lt;/p&gt;\n\nSynonyms:\nesgleam.Config\nesgleam Config","url":"esgleam.html#Config"},{"doc":"esgleam","title":"Format","content":"pub type Format {\n  Esm\n  Cjs\n  Iife\n}\n Output format of generated JavaScript\nEsm\n ECMAScript module\n\nCjs\n CommonJS\n\nIife\n immediately-invoked function expression\n\nSynonyms:\nesgleam.Format\nesgleam Format","url":"esgleam.html#Format"},{"doc":"esgleam","title":"Kind","content":"pub type Kind {\n  Script\n  Library\n}\n Kind of output\nScript\n Executes the `main()` function in your entry point\n\nLibrary\n Only exports the code\n\nSynonyms:\nesgleam.Kind\nesgleam Kind","url":"esgleam.html#Kind"},{"doc":"esgleam","title":"bundle","content":"pub fn bundle(config: Config) -&gt; Result(Nil, FileError)\n\nSynonyms:\nesgleam.bundle\nesgleam bundle","url":"esgleam.html#bundle"},{"doc":"esgleam","title":"entry","content":"pub fn entry(config: Config, path: String) -&gt; Config\n [Entry points](https://esbuild.github.io/api/#entry-points)   \n Can be use multiple times\nSynonyms:\nesgleam.entry\nesgleam entry","url":"esgleam.html#entry"},{"doc":"esgleam","title":"format","content":"pub fn format(config: Config, format: Format) -&gt; Config\n Output format. see [`Format`](#format)\nSynonyms:\nesgleam.format\nesgleam format","url":"esgleam.html#format"},{"doc":"esgleam","title":"kind","content":"pub fn kind(config: Config, kind: Kind) -&gt; Config\n Kind for output. see [`Kind`](#kind)   \n if set to `Script`, will ignore all entries except the first and will call its `main` function.\nSynonyms:\nesgleam.kind\nesgleam kind","url":"esgleam.html#kind"},{"doc":"esgleam","title":"minify","content":"pub fn minify(config: Config, do_minify: Bool) -&gt; Config\n Create minified JavaScript\nSynonyms:\nesgleam.minify\nesgleam minify","url":"esgleam.html#minify"},{"doc":"esgleam","title":"new","content":"pub fn new(outdir path: String) -&gt; Config\n Start to create a build script   \n \n &gt; esbuild.new(&quot;./dist/static&quot;)\n Config(&quot;./dist/static&quot;, ...)\n \nSynonyms:\nesgleam.new\nesgleam new","url":"esgleam.html#new"},{"doc":"esgleam","title":"raw","content":"pub fn raw(config: Config, args: String) -&gt; Config\n Raw CLI argument to pass to esbuild\nSynonyms:\nesgleam.raw\nesgleam raw","url":"esgleam.html#raw"},{"doc":"esgleam","title":"serve","content":"pub fn serve(config: Config, dir path: String) -&gt; Config\n Start a development server on http://127.0.0.1:8000 with `path` being `/`\nSynonyms:\nesgleam.serve\nesgleam serve","url":"esgleam.html#serve"},{"doc":"esgleam","title":"target","content":"pub fn target(config: Config, target: String) -&gt; Config\n [Target](https://esbuild.github.io/api/#target) for transpiled JavaScript.\n Can be used mutiple times   \n \n &gt; esbuild.new(&quot;./dist/static&quot;)\n &gt; |&gt; esbuild.target(&quot;es2020&quot;)\n &gt; |&gt; esbuild.target(&quot;firefox110&quot;)\n &gt; |&gt; esbuild.target(&quot;edge90&quot;)\n \nSynonyms:\nesgleam.target\nesgleam target","url":"esgleam.html#target"},{"doc":"esgleam","title":"watch","content":"pub fn watch(config: Config, do_watch: Bool) -&gt; Config\n Note: There is no file watcher for Gleam files so you have to manually run `gleam build` on change.\nSynonyms:\nesgleam.watch\nesgleam watch","url":"esgleam.html#watch"},{"doc":"esgleam","title":"watch_gleam","content":"pub fn watch_gleam() -&gt; fn() -&gt; Nil\n\nSynonyms:\nesgleam.watch_gleam\nesgleam watch_gleam","url":"esgleam.html#watch_gleam"},{"doc":"esgleam","title":"esgleam","content":"","url":"esgleam.html"},{"doc":"esgleam/serve","title":"main","content":"pub fn main() -&gt; Result(Nil, FileError)\n Serves the `/dist` directory as `/` on http://127.0.0.1:8000.\nSynonyms:\nesgleam/serve.main\nesgleam/serve main","url":"esgleam/serve.html#main"},{"doc":"esgleam/serve","title":"esgleam/serve","content":"","url":"esgleam/serve.html"},{"doc":"esgleam/app","title":"main","content":"pub fn main() -&gt; Result(Nil, FileError)\n Bundles `gleam.main.mjs` as a script using ESM to the `./dist` directory.   \n Will run the main function in %{project_name}.gleam\nSynonyms:\nesgleam/app.main\nesgleam/app main","url":"esgleam/app.html#main"},{"doc":"esgleam/app","title":"esgleam/app","content":"","url":"esgleam/app.html"},{"doc":"esgleam/mod/platform","title":"Arch","content":"pub type Arch {\n  X64\n  Ia32\n  Arm64\n  Arm\n  Ppc64\n}\n\nX64\n\n\nIa32\n\n\nArm64\n\n\nArm\n\n\nPpc64\n\n\nSynonyms:\nesgleam/mod/platform.Arch\nesgleam/mod/platform Arch","url":"esgleam/mod/platform.html#Arch"},{"doc":"esgleam/mod/platform","title":"OsName","content":"pub type OsName {\n  Win32\n  Linux\n  Darwin\n  Solaris\n  Sunos\n  Freebsd\n  Openbsd\n}\n\nWin32\n\n\nLinux\n\n\nDarwin\n\n\nSolaris\n\n\nSunos\n\n\nFreebsd\n\n\nOpenbsd\n\n\nSynonyms:\nesgleam/mod/platform.OsName\nesgleam/mod/platform OsName","url":"esgleam/mod/platform.html#OsName"},{"doc":"esgleam/mod/platform","title":"get_arch","content":"pub fn get_arch() -&gt; Result(Arch, Nil)\n\nSynonyms:\nesgleam/mod/platform.get_arch\nesgleam/mod/platform get_arch","url":"esgleam/mod/platform.html#get_arch"},{"doc":"esgleam/mod/platform","title":"get_os","content":"pub fn get_os() -&gt; Result(OsName, Nil)\n\nSynonyms:\nesgleam/mod/platform.get_os\nesgleam/mod/platform get_os","url":"esgleam/mod/platform.html#get_os"},{"doc":"esgleam/mod/platform","title":"get_package_name","content":"pub fn get_package_name() -&gt; String\n\nSynonyms:\nesgleam/mod/platform.get_package_name\nesgleam/mod/platform get_package_name","url":"esgleam/mod/platform.html#get_package_name"},{"doc":"esgleam/mod/platform","title":"esgleam/mod/platform","content":"","url":"esgleam/mod/platform.html"},{"doc":"esgleam/mod/install","title":"fetch","content":"pub fn fetch() -&gt; Nil\n\nSynonyms:\nesgleam/mod/install.fetch\nesgleam/mod/install fetch","url":"esgleam/mod/install.html#fetch"},{"doc":"esgleam/mod/install","title":"fetch_from_version","content":"pub fn fetch_from_version(\n  version: String,\n  then callback: fn() -&gt; Nil,\n) -&gt; Nil\n installs esbuild and take in a callback to run post install\n installs esbuild and take in a callback to run post install\nSynonyms:\nesgleam/mod/install.fetch_from_version\nesgleam/mod/install fetch_from_version","url":"esgleam/mod/install.html#fetch_from_version"},{"doc":"esgleam/mod/install","title":"fetch_latest","content":"pub fn fetch_latest(then callback: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nesgleam/mod/install.fetch_latest\nesgleam/mod/install fetch_latest","url":"esgleam/mod/install.html#fetch_latest"},{"doc":"esgleam/mod/install","title":"esgleam/mod/install","content":"","url":"esgleam/mod/install.html"},{"doc":"esgleam/bundle","title":"main","content":"pub fn main() -&gt; Result(Nil, FileError)\n Bundles {%project_name}.gleam as a library using ESM to the `./dist` directory.\nSynonyms:\nesgleam/bundle.main\nesgleam/bundle main","url":"esgleam/bundle.html#main"},{"doc":"esgleam/bundle","title":"esgleam/bundle","content":"","url":"esgleam/bundle.html"},{"doc":"esgleam/install","title":"main","content":"pub fn main() -&gt; Nil\n Installs `esbuild` (required to be run before building)    \n Run with `gleam run -m esgleam/install`\nSynonyms:\nesgleam/install.main\nesgleam/install main","url":"esgleam/install.html#main"},{"doc":"esgleam/install","title":"esgleam/install","content":"","url":"esgleam/install.html"}]);